Learn R Programming

PolisheR (version 1.1.1)

shiny_nail_qda: Launch a Shiny app for analyzing Quantitative Descriptive Analysis data (QDA)

Description

This function launches a Shiny app for analyzing QDA data with the 'Nailer' package. The app allows users to explore and analyze their QDA dataset.

Usage

shiny_nail_qda(dataset)

Value

This function does not return a value; it launches a Shiny app.

Arguments

dataset

A data frame containing the data to be analyzed.

Examples

Run this code
if(interactive()){
# Processing time is often longer than ten seconds
# because the function uses a large language model.

library(SensoMineR)
data(chocolates)
shiny_nail_qda(sensochoc)

}

Run the code above in your browser using DataLab