powered by
This function launches a Shiny app for analyzing QDA data with the 'Nailer' package. The app allows users to explore and analyze their QDA dataset.
shiny_nail_qda(dataset)
This function does not return a value; it launches a Shiny app.
A data frame containing the data to be analyzed.
if(interactive()){ # Processing time is often longer than ten seconds # because the function uses a large language model. library(SensoMineR) data(chocolates) shiny_nail_qda(sensochoc) }
Run the code above in your browser using DataLab